Index: /trunk/admin/configuration.php
===================================================================
--- /trunk/admin/configuration.php	(revision 11892)
+++ /trunk/admin/configuration.php	(revision 11893)
@@ -99,5 +99,5 @@
     'categories',
     'visits',
-    'average_rate',
+    'rating_score',
     'privacy_level',
   );
@@ -110,5 +110,5 @@
   'date_creation' => l10n('Creation date'),
   'date_available' => l10n('Post date'),
-  'average_rate' => l10n('Rating score'),
+  'rating_score' => l10n('Rating score'),
   'hit' => l10n('Most visited'),
   'id' => 'Id',
Index: /trunk/admin/element_set_ranks.php
===================================================================
--- /trunk/admin/element_set_ranks.php	(revision 11892)
+++ /trunk/admin/element_set_ranks.php	(revision 11893)
@@ -93,5 +93,5 @@
   {
     asort($_POST['rank_of_image'], SORT_NUMERIC);
-  
+
     save_images_order(
       $page['category_id'],
@@ -106,10 +106,10 @@
 
   $image_order = null;
-  if (!empty($_POST['image_order_choice']) 
+  if (!empty($_POST['image_order_choice'])
       && in_array($_POST['image_order_choice'], $image_order_choices))
   {
     $image_order_choice = $_POST['image_order_choice'];
   }
-      
+
   if ($image_order_choice=='user_define')
   {
@@ -142,5 +142,5 @@
   {
     $cat_info = get_cat_info($page['category_id']);
-    
+
     $query = '
 UPDATE '.CATEGORIES_TABLE.'
@@ -173,5 +173,5 @@
   $image_order_choice = 'rank';
 }
-elseif ($category['image_order']!='') 
+elseif ($category['image_order']!='')
 {
   $image_order_choice = 'user_define';
@@ -218,5 +218,5 @@
 	{
 		$src = get_thumbnail_url($row);
-		
+
 		$thumbnail_size = getimagesize($src);
 		if ( !empty( $row['name'] ) )
@@ -274,5 +274,5 @@
   'date_creation' => l10n('Creation date'),
   'date_available' => l10n('Post date'),
-  'average_rate' => l10n('Rating score'),
+  'rating_score' => l10n('Rating score'),
   'hit' => l10n('Most visited'),
   'file' => l10n('File name'),
Index: /trunk/admin/rating.php
===================================================================
--- /trunk/admin/rating.php	(revision 11892)
+++ /trunk/admin/rating.php	(revision 11893)
@@ -165,5 +165,5 @@
        i.file,
        i.tn_ext,
-       i.average_rate				AS score,
+       i.rating_score				AS score,
        MAX(r.date)          AS recently_rated,
 			 ROUND(AVG(r.rate),2) AS avg_rates,
@@ -177,5 +177,5 @@
         i.file,
         i.tn_ext,
-        i.average_rate,
+        i.rating_score,
         r.element_id
   ORDER BY ' . $available_order_by[$order_by_index][1] .'
Index: /trunk/admin/themes/default/template/configuration.tpl
===================================================================
--- /trunk/admin/themes/default/template/configuration.tpl	(revision 11892)
+++ /trunk/admin/themes/default/template/configuration.tpl	(revision 11893)
@@ -417,5 +417,5 @@
       <label>
         <span class="property">{'Rating score'|@translate}</span>
-        <input type="checkbox" name="picture_informations[average_rate]" {if ($display.picture_informations.average_rate)}checked="checked"{/if}>
+        <input type="checkbox" name="picture_informations[rating_score]" {if ($display.picture_informations.rating_score)}checked="checked"{/if}>
       </label>
     </li>
Index: /trunk/include/category_default.inc.php
===================================================================
--- /trunk/include/category_default.inc.php	(revision 11892)
+++ /trunk/include/category_default.inc.php	(revision 11893)
@@ -154,5 +154,5 @@
       case 'best_rated' :
       {
-        $name = '('.$row['average_rate'].') '.$name;
+        $name = '('.$row['rating_score'].') '.$name;
         break;
       }
Index: /trunk/include/config_default.inc.php
===================================================================
--- /trunk/include/config_default.inc.php	(revision 11892)
+++ /trunk/include/config_default.inc.php	(revision 11893)
@@ -497,5 +497,5 @@
 // delete from piwigo_sessions;
 // delete from piwigo_rate;
-// update piwigo_images set average_rate = null;
+// update piwigo_images set rating_score = null;
 // delete from piwigo_caddie;
 // delete from piwigo_favorites;
Index: /trunk/include/functions_category.inc.php
===================================================================
--- /trunk/include/functions_category.inc.php	(revision 11892)
+++ /trunk/include/functions_category.inc.php	(revision 11893)
@@ -291,5 +291,5 @@
     array(
     array(l10n('Default'), '', true),
-    array(l10n('Rating score'), 'average_rate DESC', $conf['rate']),
+    array(l10n('Rating score'), 'rating_score DESC', $conf['rate']),
     array(l10n('Most visited'), 'hit DESC', true),
     array(l10n('Creation date'), 'date_creation DESC', true),
@@ -560,9 +560,9 @@
   $tree = array();
   $key_of_cat = array();
-  
+
   foreach ($categories as $key => &$node)
   {
     $key_of_cat[$node['id']] = $key;
-    
+
     if (!isset($node['id_uppercat']))
     {
@@ -575,9 +575,9 @@
         $categories[ $key_of_cat[ $node['id_uppercat'] ] ]['sub_categories'] = array();
       }
-      
+
       $categories[ $key_of_cat[ $node['id_uppercat'] ] ]['sub_categories'][$key] = &$node;
     }
   }
-  
+
   return $tree;
 }
Index: /trunk/include/picture_rate.inc.php
===================================================================
--- /trunk/include/picture_rate.inc.php	(revision 11892)
+++ /trunk/include/picture_rate.inc.php	(revision 11893)
@@ -29,5 +29,5 @@
 if ($conf['rate'])
 {
-  $rate_summary = array( 'count'=>0, 'score'=>$picture['current']['average_rate'], 'average'=>null );
+  $rate_summary = array( 'count'=>0, 'score'=>$picture['current']['rating_score'], 'average'=>null );
   if ( NULL != $rate_summary['score'] )
   {
Index: /trunk/include/section_init.inc.php
===================================================================
--- /trunk/include/section_init.inc.php	(revision 11892)
+++ /trunk/include/section_init.inc.php	(revision 11893)
@@ -62,8 +62,8 @@
     break;
   }
-  
+
   // the $_GET keys are not protected in include/common.inc.php, only the values
   $rewritten = pwg_db_real_escape_string($rewritten);
-  
+
   $page['root_path'] = PHPWG_ROOT_PATH;
 }
@@ -464,7 +464,7 @@
   {
     $page['super_order_by'] = true;
-    $conf['order_by'] = ' ORDER BY hit DESC, file ASC';
+    $conf['order_by'] = ' ORDER BY hit DESC, id DESC';
     $query = '
-SELECT DISTINCT(id), hit, file
+SELECT DISTINCT(id)
   FROM '.IMAGES_TABLE.'
     INNER JOIN '.IMAGE_CATEGORY_TABLE.' AS ic ON id = ic.image_id
@@ -490,11 +490,11 @@
   {
     $page['super_order_by'] = true;
-    $conf['order_by'] = ' ORDER BY average_rate DESC, id ASC';
+    $conf['order_by'] = ' ORDER BY rating_score DESC, id DESC';
 
     $query ='
-SELECT DISTINCT(id), average_rate
+SELECT DISTINCT(id)
   FROM '.IMAGES_TABLE.'
     INNER JOIN '.IMAGE_CATEGORY_TABLE.' AS ic ON id = ic.image_id
-  WHERE average_rate IS NOT NULL
+  WHERE rating_score IS NOT NULL
     '.$forbidden.'
     '.$conf['order_by'].'
Index: /trunk/include/ws_functions.inc.php
===================================================================
--- /trunk/include/ws_functions.inc.php	(revision 11892)
+++ /trunk/include/ws_functions.inc.php	(revision 11893)
@@ -55,9 +55,9 @@
   if ( is_numeric($params['f_min_rate']) )
   {
-    $clauses[] = $tbl_name.'average_rate>'.$params['f_min_rate'];
+    $clauses[] = $tbl_name.'rating_score>'.$params['f_min_rate'];
   }
   if ( is_numeric($params['f_max_rate']) )
   {
-    $clauses[] = $tbl_name.'average_rate<='.$params['f_max_rate'];
+    $clauses[] = $tbl_name.'rating_score<='.$params['f_max_rate'];
   }
   if ( is_numeric($params['f_min_hit']) )
@@ -124,5 +124,5 @@
         $matches[1][$i] = DB_RANDOM_FUNCTION.'()'; break;
     }
-    $sortable_fields = array('id', 'file', 'name', 'hit', 'average_rate',
+    $sortable_fields = array('id', 'file', 'name', 'hit', 'rating_score',
       'date_creation', 'date_available', DB_RANDOM_FUNCTION.'()' );
     if ( in_array($matches[1][$i], $sortable_fields) )
@@ -193,5 +193,5 @@
 
   $infos['version'] = PHPWG_VERSION;
-	
+
   $query = 'SELECT COUNT(*) FROM '.IMAGES_TABLE.';';
   list($infos['nb_elements']) = pwg_db_fetch_row(pwg_query($query));
@@ -444,5 +444,5 @@
       // which is an element in the XML output. The "hierarchy" output is
       // only compatible with json/php output.
-      
+
       return new PwgError(405, "The tree_output option is only compatible with json/php output formats");
     }
@@ -472,5 +472,5 @@
     $where[] = 'status = "public"';
     $where[] = 'visible = "true"';
-    
+
     $join_user = $conf['guest_id'];
   }
@@ -480,5 +480,5 @@
     // categories. Function calculate_permissions will only return
     // categories that are either locked or private and not permitted
-    // 
+    //
     // calculate_permissions does not consider empty categories as forbidden
     $forbidden_categories = calculate_permissions($user['id'], $user['status']);
@@ -519,5 +519,5 @@
         )
       );
-    
+
     $row['comment'] = strip_tags(
       trigger_event(
@@ -527,5 +527,5 @@
         )
       );
-    
+
     array_push($cats, $row);
   }
@@ -533,5 +533,5 @@
 
   if ($params['tree_output'])
-  { 
+  {
     return categories_flatlist_to_tree($cats);
   }
@@ -782,5 +782,5 @@
   }
   //------------------------------------------------------------- related rates
-	$rating = array('score'=>$image_row['average_rate'], 'count'=>0, 'average'=>null);
+	$rating = array('score'=>$image_row['rating_score'], 'count'=>0, 'average'=>null);
 	if (isset($rating['score']))
 	{
@@ -1029,5 +1029,5 @@
     return new PwgError(401, 'Access denied');
   }
-  
+
   if (!$service->isPost())
   {
@@ -1055,5 +1055,5 @@
     return new PwgError(WS_ERR_INVALID_PARAM, "Invalid rank");
   }
-  
+
   // does the image really exist?
   $query='
@@ -1069,5 +1069,5 @@
     return new PwgError(404, "image_id not found");
   }
-  
+
   // is the image associated to this category?
   $query = '
@@ -1138,5 +1138,5 @@
 {
   global $conf;
-  
+
   ws_logfile('[ws_images_add_chunk] welcome');
   // data
@@ -1159,5 +1159,5 @@
       continue;
     }
-    
+
     ws_logfile(
       sprintf(
@@ -1219,5 +1219,5 @@
 {
   global $conf;
-  
+
   ws_logfile('[merge_chunks] input parameter $output_filepath : '.$output_filepath);
 
@@ -1287,5 +1287,5 @@
 {
   include_once(PHPWG_ROOT_PATH.'admin/include/functions_upload.inc.php');
-  
+
   $file_path = file_path_for_type($file_path, $type);
 
@@ -1298,5 +1298,5 @@
   ws_logfile('[add_file] file_path  : '.$file_path);
   ws_logfile('[add_file] upload_dir : '.$upload_dir);
-  
+
   if (!is_dir($upload_dir)) {
     umask(0000);
@@ -1446,5 +1446,5 @@
     $where_clause = "file = '".$params['original_filename']."'";
   }
-  
+
   $query = '
 SELECT
@@ -1550,5 +1550,5 @@
   require_once(PHPWG_ROOT_PATH.'admin/include/functions_metadata.php');
   update_metadata(array($image_id=>$file_path));
-  
+
   invalidate_user_cache();
 }
@@ -1571,5 +1571,5 @@
     return new PwgError(405, "The image (file) parameter is missing");
   }
-  
+
   $params['image_id'] = (int)$params['image_id'];
   if ($params['image_id'] > 0)
@@ -1677,5 +1677,5 @@
 ;';
   list($file_path) = pwg_db_fetch_row(pwg_query($query));
-  
+
   require_once(PHPWG_ROOT_PATH.'admin/include/functions_metadata.php');
   update_metadata(array($image_id=>$file_path));
@@ -1732,5 +1732,5 @@
   list($dbnow) = pwg_db_fetch_row(pwg_query('SELECT NOW();'));
   $res['current_datetime'] = $dbnow;
-  
+
   return $res;
 }
@@ -1827,5 +1827,5 @@
 
   $image_ids = array_slice($image_ids, (int)($params['per_page']*$params['page']), (int)$params['per_page'] );
-  
+
   $image_tag_map = array();
   if ( !empty($image_ids) and !$params['tag_mode_and'] )
@@ -1963,5 +1963,5 @@
 {
   global $conf;
-  
+
   if (!is_admin())
   {
@@ -2002,5 +2002,5 @@
     }
   }
-  
+
   if ('filename' == $conf['uniqueness_mode'])
   {
@@ -2481,5 +2481,5 @@
 {
   global $conf;
-  
+
   if (!is_admin())
   {
@@ -2519,5 +2519,5 @@
     return new PwgError(WS_ERR_INVALID_PARAM, "Invalid image_id");
   }
-  
+
   // does the image really exist?
   $query='
@@ -2612,5 +2612,5 @@
     return;
   }
-  
+
   include_once(PHPWG_ROOT_PATH.'admin/include/functions.php');
   delete_categories($category_ids, $params['photo_deletion_mode']);
@@ -2621,5 +2621,5 @@
 {
   global $conf, $page;
-  
+
   if (!is_admin())
   {
@@ -2661,5 +2661,5 @@
   // we can't move physical categories
   $categories_in_db = array();
-  
+
   $query = '
 SELECT
@@ -2684,5 +2684,5 @@
           )
         );
-      
+
       return new PwgError(
         403,
@@ -2699,5 +2699,5 @@
   {
     $unknown_category_ids = array_diff($category_ids, array_keys($categories_in_db));
-    
+
     return new PwgError(
       403,
@@ -2717,5 +2717,5 @@
     return new PwgError(403, 'Invalid parent input parameter');
   }
-  
+
   if (0 != $params['parent']) {
     $params['parent'] = intval($params['parent']);
@@ -2766,10 +2766,10 @@
   $ret['message'] = ready_for_upload_message();
   $ret['ready_for_upload'] = true;
-  
+
   if (!empty($ret['message']))
   {
     $ret['ready_for_upload'] = false;
   }
-  
+
   return $ret;
 }
@@ -2778,5 +2778,5 @@
 {
   global $conf;
-  
+
   if (!is_admin())
   {
@@ -2818,5 +2818,5 @@
 {
   global $template;
-  
+
   if (!is_admin())
   {
@@ -2834,5 +2834,5 @@
   $errors = $plugins->perform_action($params['action'], $params['plugin']);
 
-  
+
   if (!empty($errors))
   {
@@ -2852,5 +2852,5 @@
 {
   global $template;
-  
+
   if (!is_admin())
   {
@@ -2867,5 +2867,5 @@
   $themes = new themes();
   $errors = $themes->perform_action($params['action'], $params['theme']);
-  
+
   if (!empty($errors))
   {
@@ -3045,5 +3045,5 @@
       );
     }
-    
+
     $upgrade_status = $extension->extract_plugin_files('upgrade', $revision, $extension_id);
     $extension_name = $extension->fs_plugins[$extension_id]['name'];
Index: /trunk/install/config.sql
===================================================================
--- /trunk/install/config.sql	(revision 11892)
+++ /trunk/install/config.sql	(revision 11893)
@@ -48,5 +48,5 @@
   VALUES (
     'picture_informations',
-    'a:11:{s:6:"author";b:1;s:10:"created_on";b:1;s:9:"posted_on";b:1;s:10:"dimensions";b:1;s:4:"file";b:1;s:8:"filesize";b:1;s:4:"tags";b:1;s:10:"categories";b:1;s:6:"visits";b:1;s:12:"average_rate";b:1;s:13:"privacy_level";b:1;}',
+    'a:11:{s:6:"author";b:1;s:10:"created_on";b:1;s:9:"posted_on";b:1;s:10:"dimensions";b:1;s:4:"file";b:1;s:8:"filesize";b:1;s:4:"tags";b:1;s:10:"categories";b:1;s:6:"visits";b:1;s:12:"rating_score";b:1;s:13:"privacy_level";b:1;}',
     'Information displayed on picture page'
   );
Index: /trunk/install/db/109-database.php
===================================================================
--- /trunk/install/db/109-database.php	(revision 11893)
+++ /trunk/install/db/109-database.php	(revision 11893)
@@ -0,0 +1,41 @@
+<?php
+// +-----------------------------------------------------------------------+
+// | Piwigo - a PHP based photo gallery                                    |
+// +-----------------------------------------------------------------------+
+// | Copyright(C) 2008-2011 Piwigo Team                  http://piwigo.org |
+// | Copyright(C) 2003-2008 PhpWebGallery Team    http://phpwebgallery.net |
+// | Copyright(C) 2002-2003 Pierrick LE GALL   http://le-gall.net/pierrick |
+// +-----------------------------------------------------------------------+
+// | This program is free software; you can redistribute it and/or modify  |
+// | it under the terms of the GNU General Public License as published by  |
+// | the Free Software Foundation                                          |
+// |                                                                       |
+// | This program is distributed in the hope that it will be useful, but   |
+// | WITHOUT ANY WARRANTY; without even the implied warranty of            |
+// | MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU      |
+// | General Public License for more details.                              |
+// |                                                                       |
+// | You should have received a copy of the GNU General Public License     |
+// | along with this program; if not, write to the Free Software           |
+// | Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, |
+// | USA.                                                                  |
+// +-----------------------------------------------------------------------+
+
+defined('PHPWG_ROOT_PATH') or die('Hacking attempt!');
+
+$upgrade_description = 'Rename #images.average_rate to ratingscore.';
+include_once(PHPWG_ROOT_PATH.'include/constants.php');
+
+if ('mysql' == $conf['dblayer'])
+  $q = 'ALTER TABLE '.IMAGES_TABLE.' CHANGE average_rate rating_score float(5,2) unsigned default NULL';
+else
+  $q = 'ALTER TABLE '.IMAGES_TABLE.' RENAME average_rate TO rating_score';
+pwg_query($q);
+
+$q="UPDATE ".CATEGORIES_TABLE." SET image_order=REPLACE(image_order, 'average_rate', 'rating_score')";
+pwg_query($q);
+
+$q="UPDATE ".CONFIG_TABLE." SET value=REPLACE(value, 'average_rate', 'rating_score')
+WHERE param IN ('picture_informations', 'order_by', 'order_by_inside_category')";
+pwg_query($q);
+?>
Index: /trunk/install/piwigo_structure-mysql.sql
===================================================================
--- /trunk/install/piwigo_structure-mysql.sql	(revision 11892)
+++ /trunk/install/piwigo_structure-mysql.sql	(revision 11893)
@@ -188,5 +188,5 @@
   `representative_ext` varchar(4) default NULL,
   `date_metadata_update` date default NULL,
-  `average_rate` float(5,2) unsigned default NULL,
+  `rating_score` float(5,2) unsigned default NULL,
   `has_high` enum('true') default NULL,
   `path` varchar(255) NOT NULL default '',
@@ -200,5 +200,5 @@
   PRIMARY KEY  (`id`),
   KEY `images_i2` (`date_available`),
-  KEY `images_i3` (`average_rate`),
+  KEY `images_i3` (`rating_score`),
   KEY `images_i4` (`hit`),
   KEY `images_i5` (`date_creation`),
Index: /trunk/install/piwigo_structure-pdo-sqlite.sql
===================================================================
--- /trunk/install/piwigo_structure-pdo-sqlite.sql	(revision 11892)
+++ /trunk/install/piwigo_structure-pdo-sqlite.sql	(revision 11893)
@@ -184,5 +184,5 @@
   "representative_ext" VARCHAR(4),
   "date_metadata_update" DATE,
-  "average_rate" FLOAT,
+  "rating_score" FLOAT,
   "has_high" BOOLEAN default false,
   "path" VARCHAR(255) default '' NOT NULL,
@@ -200,5 +200,5 @@
 CREATE INDEX "images_i2" ON "piwigo_images" ("date_available");
 
-CREATE INDEX "images_i3" ON "piwigo_images" ("average_rate");
+CREATE INDEX "images_i3" ON "piwigo_images" ("rating_score");
 
 CREATE INDEX "images_i4" ON "piwigo_images" ("hit");
Index: /trunk/install/piwigo_structure-pgsql.sql
===================================================================
--- /trunk/install/piwigo_structure-pgsql.sql	(revision 11892)
+++ /trunk/install/piwigo_structure-pgsql.sql	(revision 11893)
@@ -228,5 +228,5 @@
   "representative_ext" VARCHAR(4),
   "date_metadata_update" DATE,
-  "average_rate" FLOAT,
+  "rating_score" FLOAT,
   "has_high" BOOLEAN default false,
   "path" VARCHAR(255) default '' NOT NULL,
@@ -247,5 +247,5 @@
 CREATE INDEX "images_i2" ON "piwigo_images" ("date_available");
 
-CREATE INDEX "images_i3" ON "piwigo_images" ("average_rate");
+CREATE INDEX "images_i3" ON "piwigo_images" ("rating_score");
 
 CREATE INDEX "images_i4" ON "piwigo_images" ("hit");
Index: /trunk/install/piwigo_structure-sqlite.sql
===================================================================
--- /trunk/install/piwigo_structure-sqlite.sql	(revision 11892)
+++ /trunk/install/piwigo_structure-sqlite.sql	(revision 11893)
@@ -184,5 +184,5 @@
   "representative_ext" VARCHAR(4),
   "date_metadata_update" DATE,
-  "average_rate" FLOAT,
+  "rating_score" FLOAT,
   "has_high" BOOLEAN default false,
   "path" VARCHAR(255) default '' NOT NULL,
@@ -200,5 +200,5 @@
 CREATE INDEX "images_i2" ON "piwigo_images" ("date_available");
 
-CREATE INDEX "images_i3" ON "piwigo_images" ("average_rate");
+CREATE INDEX "images_i3" ON "piwigo_images" ("rating_score");
 
 CREATE INDEX "images_i4" ON "piwigo_images" ("hit");
Index: /trunk/language/it_IT/help/configuration.html
===================================================================
--- /trunk/language/it_IT/help/configuration.html	(revision 11892)
+++ /trunk/language/it_IT/help/configuration.html	(revision 11893)
@@ -44,5 +44,5 @@
       <li><b>name</b> : nome della foto</li>
       <li><b>hit</b> : numero di visite</li>
-      <li><b>average_rate</b>: nota globbale</li>
+      <li><b>rating_score</b>: nota globbale</li>
     </ul>
     Non dimenticate che per ogni campo di specificare l'ordinamento con le parole chiavi <i>ASC</i> e <i>DESC</i>
Index: /trunk/themes/default/template/picture.tpl
===================================================================
--- /trunk/themes/default/template/picture.tpl	(revision 11892)
+++ /trunk/themes/default/template/picture.tpl	(revision 11893)
@@ -195,5 +195,5 @@
 	{/if}
 
-{if $display_info.average_rate and isset($rate_summary)}
+{if $display_info.rating_score and isset($rate_summary)}
 	<tr id="Average">
 		<td class="label">{'Rating score'|@translate}</td>
Index: /trunk/ws.php
===================================================================
--- /trunk/ws.php	(revision 11892)
+++ /trunk/ws.php	(revision 11893)
@@ -74,5 +74,5 @@
       'Returns elements for the corresponding categories.
 <br><b>cat_id</b> can be empty if <b>recursive</b> is true. Can be sent as an array.
-<br><b>order</b> comma separated fields for sorting (file,id, average_rate,...)'
+<br><b>order</b> comma separated fields for sorting (file,id, rating_score,...)'
     );
 

Index: /trunk/include/functions_rate.inc.php
===================================================================
--- /trunk/include/functions_rate.inc.php	(revision 11892)
+++ /trunk/include/functions_rate.inc.php	(revision 11893)
@@ -121,5 +121,5 @@
 
 
 /* update images.average_rate field
   * we use a bayesian average (http://en.wikipedia.org/wiki/Bayesian_average) with
 C = average number of rates per item
@@ -127,5 +127,5 @@
 
  * param int $element_id optional, otherwise applies to all
  * @return array(average_rate, count) if element_id is specified
 */
 function update_rating_score($element_id = false)
@@ -167,5 +167,5 @@
         );
     }
-    $updates[] = array( 'id'=>$id, 'average_rate'=>$score );
+    $updates[] = array( 'id'=>$id, 'rating_score'=>$score );
   }
   mass_updates(
@@ -173,5 +173,5 @@
     array(
       'primary' => array('id'),
-      'update' => array('average_rate')
+      'update' => array('rating_score')
       ),
     $updates
@@ -184,5 +184,5 @@
 SELECT id FROM '.IMAGES_TABLE .'
   LEFT JOIN '.RATE_TABLE.' ON id=element_id
-  WHERE element_id IS NULL AND average_rate IS NOT NULL';
+  WHERE element_id IS NULL AND rating_score IS NOT NULL';
 
     $to_update = array_from_query( $query, 'id');
@@ -192,5 +192,5 @@
       $query='
 UPDATE '.IMAGES_TABLE .'
-  SET average_rate=NULL
+  SET rating_score=NULL
   WHERE id IN (' . implode(',',$to_update) . ')';
     pwg_query($query);
@@ -121,5 +121,5 @@
 
 
-/* update images.average_rate field
+/* update images.rating_score field
   * we use a bayesian average (http://en.wikipedia.org/wiki/Bayesian_average) with
 C = average number of rates per item
@@ -127,5 +127,5 @@
 
  * param int $element_id optional, otherwise applies to all
- * @return array(average_rate, count) if element_id is specified
+ * @return array(rating_score, count) if element_id is specified
 */
 function update_rating_score($element_id = false)